# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
# Generated file, DO NOT EDIT
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------------------------

from .agent_pool_queue import AgentPoolQueue
from .aggregated_results_analysis import AggregatedResultsAnalysis
from .aggregated_results_by_outcome import AggregatedResultsByOutcome
from .aggregated_results_difference import AggregatedResultsDifference
from .aggregated_runs_by_state import AggregatedRunsByState
from .artifact_resource import ArtifactResource
from .associated_work_item import AssociatedWorkItem
from .attachment import Attachment
from .authorization_header import AuthorizationHeader
from .build import Build
from .build_artifact import BuildArtifact
from .build_badge import BuildBadge
from .build_controller import BuildController
from .build_definition import BuildDefinition
from .build_definition3_2 import BuildDefinition3_2
from .build_definition_counter import BuildDefinitionCounter
from .build_definition_reference import BuildDefinitionReference
from .build_definition_reference3_2 import BuildDefinitionReference3_2
from .build_definition_revision import BuildDefinitionRevision
from .build_definition_step import BuildDefinitionStep
from .build_definition_template import BuildDefinitionTemplate
from .build_definition_template3_2 import BuildDefinitionTemplate3_2
from .build_definition_variable import BuildDefinitionVariable
from .build_log import BuildLog
from .build_log_reference import BuildLogReference
from .build_metric import BuildMetric
from .build_option import BuildOption
from .build_option_definition import BuildOptionDefinition
from .build_option_definition_reference import BuildOptionDefinitionReference
from .build_option_group_definition import BuildOptionGroupDefinition
from .build_option_input_definition import BuildOptionInputDefinition
from .build_report_metadata import BuildReportMetadata
from .build_repository import BuildRepository
from .build_request_validation_result import BuildRequestValidationResult
from .build_resource_usage import BuildResourceUsage
from .build_settings import BuildSettings
from .change import Change
from .data_source_binding_base import DataSourceBindingBase
from .definition_reference import DefinitionReference
from .deployment import Deployment
from .folder import Folder
from .graph_subject_base import GraphSubjectBase
from .identity_ref import IdentityRef
from .issue import Issue
from .json_patch_operation import JsonPatchOperation
from .process_parameters import ProcessParameters
from .reference_links import ReferenceLinks
from .release_reference import ReleaseReference
from .repository_webhook import RepositoryWebhook
from .resource_ref import ResourceRef
from .retention_policy import RetentionPolicy
from .source_provider_attributes import SourceProviderAttributes
from .source_repositories import SourceRepositories
from .source_repository import SourceRepository
from .source_repository_item import SourceRepositoryItem
from .supported_trigger import SupportedTrigger
from .task_agent_pool_reference import TaskAgentPoolReference
from .task_definition_reference import TaskDefinitionReference
from .task_input_definition_base import TaskInputDefinitionBase
from .task_input_validation import TaskInputValidation
from .task_orchestration_plan_reference import TaskOrchestrationPlanReference
from .task_reference import TaskReference
from .task_source_definition_base import TaskSourceDefinitionBase
from .team_project_reference import TeamProjectReference
from .test_results_context import TestResultsContext
from .timeline import Timeline
from .timeline_record import TimelineRecord
from .timeline_reference import TimelineReference
from .variable_group import VariableGroup
from .variable_group_reference import VariableGroupReference
from .web_api_connected_service_ref import WebApiConnectedServiceRef
from .xaml_build_controller_reference import XamlBuildControllerReference

__all__ = [
    'AgentPoolQueue',
    'AggregatedResultsAnalysis',
    'AggregatedResultsByOutcome',
    'AggregatedResultsDifference',
    'AggregatedRunsByState',
    'ArtifactResource',
    'AssociatedWorkItem',
    'Attachment',
    'AuthorizationHeader',
    'Build',
    'BuildArtifact',
    'BuildBadge',
    'BuildController',
    'BuildDefinition',
    'BuildDefinition3_2',
    'BuildDefinitionCounter',
    'BuildDefinitionReference',
    'BuildDefinitionReference3_2',
    'BuildDefinitionRevision',
    'BuildDefinitionStep',
    'BuildDefinitionTemplate',
    'BuildDefinitionTemplate3_2',
    'BuildDefinitionVariable',
    'BuildLog',
    'BuildLogReference',
    'BuildMetric',
    'BuildOption',
    'BuildOptionDefinition',
    'BuildOptionDefinitionReference',
    'BuildOptionGroupDefinition',
    'BuildOptionInputDefinition',
    'BuildReportMetadata',
    'BuildRepository',
    'BuildRequestValidationResult',
    'BuildResourceUsage',
    'BuildSettings',
    'Change',
    'DataSourceBindingBase',
    'DefinitionReference',
    'Deployment',
    'Folder',
    'GraphSubjectBase',
    'IdentityRef',
    'Issue',
    'JsonPatchOperation',
    'ProcessParameters',
    'ReferenceLinks',
    'ReleaseReference',
    'RepositoryWebhook',
    'ResourceRef',
    'RetentionPolicy',
    'SourceProviderAttributes',
    'SourceRepositories',
    'SourceRepository',
    'SourceRepositoryItem',
    'SupportedTrigger',
    'TaskAgentPoolReference',
    'TaskDefinitionReference',
    'TaskInputDefinitionBase',
    'TaskInputValidation',
    'TaskOrchestrationPlanReference',
    'TaskReference',
    'TaskSourceDefinitionBase',
    'TeamProjectReference',
    'TestResultsContext',
    'Timeline',
    'TimelineRecord',
    'TimelineReference',
    'VariableGroup',
    'VariableGroupReference',
    'WebApiConnectedServiceRef',
    'XamlBuildControllerReference',
]
