# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
# Generated file, DO NOT EDIT
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------------------------

from .associated_work_item import AssociatedWorkItem
from .change import Change
from .checkin_note import CheckinNote
from .file_content_metadata import FileContentMetadata
from .git_repository import GitRepository
from .git_repository_ref import GitRepositoryRef
from .identity_ref import IdentityRef
from .item_content import ItemContent
from .item_model import ItemModel
from .reference_links import ReferenceLinks
from .team_project_collection_reference import TeamProjectCollectionReference
from .team_project_reference import TeamProjectReference
from .tfvc_branch import TfvcBranch
from .tfvc_branch_mapping import TfvcBranchMapping
from .tfvc_branch_ref import TfvcBranchRef
from .tfvc_change import TfvcChange
from .tfvc_changeset import TfvcChangeset
from .tfvc_changeset_ref import TfvcChangesetRef
from .tfvc_changeset_search_criteria import TfvcChangesetSearchCriteria
from .tfvc_changesets_request_data import TfvcChangesetsRequestData
from .tfvc_item import TfvcItem
from .tfvc_item_descriptor import TfvcItemDescriptor
from .tfvc_item_request_data import TfvcItemRequestData
from .tfvc_label import TfvcLabel
from .tfvc_label_ref import TfvcLabelRef
from .tfvc_label_request_data import TfvcLabelRequestData
from .tfvc_merge_source import TfvcMergeSource
from .tfvc_policy_failure_info import TfvcPolicyFailureInfo
from .tfvc_policy_override_info import TfvcPolicyOverrideInfo
from .tfvc_shallow_branch_ref import TfvcShallowBranchRef
from .tfvc_shelveset import TfvcShelveset
from .tfvc_shelveset_ref import TfvcShelvesetRef
from .tfvc_shelveset_request_data import TfvcShelvesetRequestData
from .tfvc_version_descriptor import TfvcVersionDescriptor
from .version_control_project_info import VersionControlProjectInfo
from .vsts_info import VstsInfo

__all__ = [
    'AssociatedWorkItem',
    'Change',
    'CheckinNote',
    'FileContentMetadata',
    'GitRepository',
    'GitRepositoryRef',
    'IdentityRef',
    'ItemContent',
    'ItemModel',
    'ReferenceLinks',
    'TeamProjectCollectionReference',
    'TeamProjectReference',
    'TfvcBranch',
    'TfvcBranchMapping',
    'TfvcBranchRef',
    'TfvcChange',
    'TfvcChangeset',
    'TfvcChangesetRef',
    'TfvcChangesetSearchCriteria',
    'TfvcChangesetsRequestData',
    'TfvcItem',
    'TfvcItemDescriptor',
    'TfvcItemRequestData',
    'TfvcLabel',
    'TfvcLabelRef',
    'TfvcLabelRequestData',
    'TfvcMergeSource',
    'TfvcPolicyFailureInfo',
    'TfvcPolicyOverrideInfo',
    'TfvcShallowBranchRef',
    'TfvcShelveset',
    'TfvcShelvesetRef',
    'TfvcShelvesetRequestData',
    'TfvcVersionDescriptor',
    'VersionControlProjectInfo',
    'VstsInfo',
]
