# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
# Generated file, DO NOT EDIT
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------------------------

from .account_entitlement import AccountEntitlement
from .account_entitlement_update_model import AccountEntitlementUpdateModel
from .account_license_extension_usage import AccountLicenseExtensionUsage
from .account_license_usage import AccountLicenseUsage
from .account_rights import AccountRights
from .account_user_license import AccountUserLicense
from .client_rights_container import ClientRightsContainer
from .extension_assignment import ExtensionAssignment
from .extension_assignment_details import ExtensionAssignmentDetails
from .extension_license_data import ExtensionLicenseData
from .extension_operation_result import ExtensionOperationResult
from .extension_rights_result import ExtensionRightsResult
from .extension_source import ExtensionSource
from .identity_ref import IdentityRef
from .iUsage_right import IUsageRight
from .license import License
from .msdn_entitlement import MsdnEntitlement

__all__ = [
    'AccountEntitlement',
    'AccountEntitlementUpdateModel',
    'AccountLicenseExtensionUsage',
    'AccountLicenseUsage',
    'AccountRights',
    'AccountUserLicense',
    'ClientRightsContainer',
    'ExtensionAssignment',
    'ExtensionAssignmentDetails',
    'ExtensionLicenseData',
    'ExtensionOperationResult',
    'ExtensionRightsResult',
    'ExtensionSource',
    'IdentityRef',
    'IUsageRight',
    'License',
    'MsdnEntitlement',
]
