# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
# Generated file, DO NOT EDIT
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------------------------

from .feature_flag import FeatureFlag
from .feature_flag_patch import FeatureFlagPatch

__all__ = [
    'FeatureFlag',
    'FeatureFlagPatch',
]
