# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
# Generated file, DO NOT EDIT
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------------------------

from .agent_artifact_definition import AgentArtifactDefinition
from .approval_options import ApprovalOptions
from .artifact import Artifact
from .artifact_metadata import ArtifactMetadata
from .artifact_source_reference import ArtifactSourceReference
from .artifact_type_definition import ArtifactTypeDefinition
from .artifact_version import ArtifactVersion
from .artifact_version_query_result import ArtifactVersionQueryResult
from .authorization_header import AuthorizationHeader
from .auto_trigger_issue import AutoTriggerIssue
from .build_version import BuildVersion
from .change import Change
from .condition import Condition
from .configuration_variable_value import ConfigurationVariableValue
from .data_source_binding_base import DataSourceBindingBase
from .definition_environment_reference import DefinitionEnvironmentReference
from .deployment import Deployment
from .deployment_attempt import DeploymentAttempt
from .deployment_job import DeploymentJob
from .deployment_query_parameters import DeploymentQueryParameters
from .email_recipients import EmailRecipients
from .environment_execution_policy import EnvironmentExecutionPolicy
from .environment_options import EnvironmentOptions
from .environment_retention_policy import EnvironmentRetentionPolicy
from .favorite_item import FavoriteItem
from .folder import Folder
from .graph_subject_base import GraphSubjectBase
from .identity_ref import IdentityRef
from .input_descriptor import InputDescriptor
from .input_validation import InputValidation
from .input_value import InputValue
from .input_values import InputValues
from .input_values_error import InputValuesError
from .input_values_query import InputValuesQuery
from .issue import Issue
from .mail_message import MailMessage
from .manual_intervention import ManualIntervention
from .manual_intervention_update_metadata import ManualInterventionUpdateMetadata
from .metric import Metric
from .pipeline_process import PipelineProcess
from .process_parameters import ProcessParameters
from .project_reference import ProjectReference
from .queued_release_data import QueuedReleaseData
from .reference_links import ReferenceLinks
from .release import Release
from .release_approval import ReleaseApproval
from .release_approval_history import ReleaseApprovalHistory
from .release_condition import ReleaseCondition
from .release_definition import ReleaseDefinition
from .release_definition_approvals import ReleaseDefinitionApprovals
from .release_definition_approval_step import ReleaseDefinitionApprovalStep
from .release_definition_deploy_step import ReleaseDefinitionDeployStep
from .release_definition_environment import ReleaseDefinitionEnvironment
from .release_definition_environment_step import ReleaseDefinitionEnvironmentStep
from .release_definition_environment_summary import ReleaseDefinitionEnvironmentSummary
from .release_definition_environment_template import ReleaseDefinitionEnvironmentTemplate
from .release_definition_gate import ReleaseDefinitionGate
from .release_definition_gates_options import ReleaseDefinitionGatesOptions
from .release_definition_gates_step import ReleaseDefinitionGatesStep
from .release_definition_revision import ReleaseDefinitionRevision
from .release_definition_shallow_reference import ReleaseDefinitionShallowReference
from .release_definition_summary import ReleaseDefinitionSummary
from .release_definition_undelete_parameter import ReleaseDefinitionUndeleteParameter
from .release_deploy_phase import ReleaseDeployPhase
from .release_environment import ReleaseEnvironment
from .release_environment_shallow_reference import ReleaseEnvironmentShallowReference
from .release_environment_update_metadata import ReleaseEnvironmentUpdateMetadata
from .release_gates import ReleaseGates
from .release_reference import ReleaseReference
from .release_revision import ReleaseRevision
from .release_schedule import ReleaseSchedule
from .release_settings import ReleaseSettings
from .release_shallow_reference import ReleaseShallowReference
from .release_start_metadata import ReleaseStartMetadata
from .release_task import ReleaseTask
from .release_task_attachment import ReleaseTaskAttachment
from .release_trigger_base import ReleaseTriggerBase
from .release_update_metadata import ReleaseUpdateMetadata
from .release_work_item_ref import ReleaseWorkItemRef
from .retention_policy import RetentionPolicy
from .retention_settings import RetentionSettings
from .summary_mail_section import SummaryMailSection
from .task_input_definition_base import TaskInputDefinitionBase
from .task_input_validation import TaskInputValidation
from .task_source_definition_base import TaskSourceDefinitionBase
from .variable_group import VariableGroup
from .variable_group_provider_data import VariableGroupProviderData
from .variable_value import VariableValue
from .workflow_task import WorkflowTask
from .workflow_task_reference import WorkflowTaskReference

__all__ = [
    'AgentArtifactDefinition',
    'ApprovalOptions',
    'Artifact',
    'ArtifactMetadata',
    'ArtifactSourceReference',
    'ArtifactTypeDefinition',
    'ArtifactVersion',
    'ArtifactVersionQueryResult',
    'AuthorizationHeader',
    'AutoTriggerIssue',
    'BuildVersion',
    'Change',
    'Condition',
    'ConfigurationVariableValue',
    'DataSourceBindingBase',
    'DefinitionEnvironmentReference',
    'Deployment',
    'DeploymentAttempt',
    'DeploymentJob',
    'DeploymentQueryParameters',
    'EmailRecipients',
    'EnvironmentExecutionPolicy',
    'EnvironmentOptions',
    'EnvironmentRetentionPolicy',
    'FavoriteItem',
    'Folder',
    'GraphSubjectBase',
    'IdentityRef',
    'InputDescriptor',
    'InputValidation',
    'InputValue',
    'InputValues',
    'InputValuesError',
    'InputValuesQuery',
    'Issue',
    'MailMessage',
    'ManualIntervention',
    'ManualInterventionUpdateMetadata',
    'Metric',
    'PipelineProcess',
    'ProcessParameters',
    'ProjectReference',
    'QueuedReleaseData',
    'ReferenceLinks',
    'Release',
    'ReleaseApproval',
    'ReleaseApprovalHistory',
    'ReleaseCondition',
    'ReleaseDefinition',
    'ReleaseDefinitionApprovals',
    'ReleaseDefinitionApprovalStep',
    'ReleaseDefinitionDeployStep',
    'ReleaseDefinitionEnvironment',
    'ReleaseDefinitionEnvironmentStep',
    'ReleaseDefinitionEnvironmentSummary',
    'ReleaseDefinitionEnvironmentTemplate',
    'ReleaseDefinitionGate',
    'ReleaseDefinitionGatesOptions',
    'ReleaseDefinitionGatesStep',
    'ReleaseDefinitionRevision',
    'ReleaseDefinitionShallowReference',
    'ReleaseDefinitionSummary',
    'ReleaseDefinitionUndeleteParameter',
    'ReleaseDeployPhase',
    'ReleaseEnvironment',
    'ReleaseEnvironmentShallowReference',
    'ReleaseEnvironmentUpdateMetadata',
    'ReleaseGates',
    'ReleaseReference',
    'ReleaseRevision',
    'ReleaseSchedule',
    'ReleaseSettings',
    'ReleaseShallowReference',
    'ReleaseStartMetadata',
    'ReleaseTask',
    'ReleaseTaskAttachment',
    'ReleaseTriggerBase',
    'ReleaseUpdateMetadata',
    'ReleaseWorkItemRef',
    'RetentionPolicy',
    'RetentionSettings',
    'SummaryMailSection',
    'TaskInputDefinitionBase',
    'TaskInputValidation',
    'TaskSourceDefinitionBase',
    'VariableGroup',
    'VariableGroupProviderData',
    'VariableValue',
    'WorkflowTask',
    'WorkflowTaskReference',
]
