# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
# Generated file, DO NOT EDIT
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------------------------

from .identity_data import IdentityData
from .identity_ref import IdentityRef
from .json_patch_operation import JsonPatchOperation
from .operation_reference import OperationReference
from .process import Process
from .process_reference import ProcessReference
from .project_info import ProjectInfo
from .project_property import ProjectProperty
from .proxy import Proxy
from .proxy_authorization import ProxyAuthorization
from .public_key import PublicKey
from .reference_links import ReferenceLinks
from .team_project import TeamProject
from .team_project_collection import TeamProjectCollection
from .team_project_collection_reference import TeamProjectCollectionReference
from .team_project_reference import TeamProjectReference
from .web_api_connected_service import WebApiConnectedService
from .web_api_connected_service_details import WebApiConnectedServiceDetails
from .web_api_connected_service_ref import WebApiConnectedServiceRef
from .web_api_team import WebApiTeam
from .web_api_team_ref import WebApiTeamRef

__all__ = [
    'IdentityData',
    'IdentityRef',
    'JsonPatchOperation',
    'OperationReference',
    'Process',
    'ProcessReference',
    'ProjectInfo',
    'ProjectProperty',
    'Proxy',
    'ProxyAuthorization',
    'PublicKey',
    'ReferenceLinks',
    'TeamProject',
    'TeamProjectCollection',
    'TeamProjectCollectionReference',
    'TeamProjectReference',
    'WebApiConnectedService',
    'WebApiConnectedServiceDetails',
    'WebApiConnectedServiceRef',
    'WebApiTeam',
    'WebApiTeamRef',
]
